<?php

App::uses('AppHelper', 'View/Helper');

class InventoryHelper extends AppHelper {

	/**
	 * show item based on stock level and options
	 *
	 * @param 	array 	$item 	Item array containing subarray of Inventory data
	 * @return 	bool
	 */
	public function allowPurchase($item) {
		if (isset($item['Inventory']['stock']) && $item['Inventory']['stock'] > 0) {
			return true;
		}

		if (! isset($item['Inventory']['oos_action']) || ! in_array('stop', $item['Inventory']['oos_action'])) {
			return true;
		}

		return false;
	}

	/**
	 * check if we need to show the delayed message
	 *
	 * @param 	array 	$item 	Item array containing subarray of Inventory data
	 * @return 	bool
	 */
	public function showDelayedMessage($item) {
		if (
			(! isset($item['Inventory']['stock']) || $item['Inventory']['stock'] <= 0) &&
			(
				isset($item['Inventory']['oos_action']) &&
				is_array($item['Inventory']['oos_action']) &&
				in_array('delayed', $item['Inventory']['oos_action'])
			)
		) {
			return true;
		}

		return false;
	}

	/**
	 * check to see if it has low stock
	 *
	 * @param 	array 	$item 	Item array containing subarray of Inventory data
	 * @return 	bool
	 */
	public function showLowStockMessage($item) {
		if (
			(
				is_array($item['Inventory']['warning_action']) &&
				isset($item['Inventory']['warning_action']) &&
				in_array('warning', $item['Inventory']['warning_action'])
			) &&
			isset($item['Inventory']['stock']) &&
			$item['Inventory']['stock'] <= $item['Inventory']['warning_level'] &&
			$item['Inventory']['stock'] > 0
		) {
			return true;
		}

		return false;
	}

	/**
	 * show out of stock message
	 *
	 * @return string
	 */
	public function oosMessage() {
		return Configure::read('EvInventory.oosMessage');
	}

	/**
	 * show the delayed message
	 *
	 * @return string
	 */
	public function delayedMessage() {
		return Configure::read('EvInventory.delayedMessage');
	}

	/**
	 * show the low stock level message
	 *
	 * @return string
	 */
	public function lowStockMessage() {
		return Configure::read('EvInventory.lowStockMessage');
	}
}
